@@ -1,11 +1,13 @@
 import difflib
-from typing import List, Tuple, Dict, Optional, Callable, Set
-
-from typing import TYPE_CHECKING
+from typing import List, Tuple, Dict, Optional, Callable, Set, TYPE_CHECKING
 
 if TYPE_CHECKING:
     from tinycoder.file_manager import FileManager
     from tinycoder.git_manager import GitManager
+    from prompt_toolkit.styles import Style
+
+from prompt_toolkit import print_formatted_text
+from prompt_toolkit.formatted_text import FormattedText
 
 from tinycoder.linters.python_linter import PythonLinter
 from tinycoder.linters.html_linter import HTMLLinter
@@ -24,6 +26,7 @@ class CodeApplier:
         file_manager: "FileManager",
         git_manager: "GitManager",
         input_func: Callable[[str], str],
+        style: Optional["Style"] = None,
     ):
         """
         Initializes the CodeApplier.
@@ -32,17 +35,19 @@ class CodeApplier:
             file_manager: An instance of FileManager.
             git_manager: An instance of GitManager (used for context).
             input_func: Function to use for user input (like confirmation).
+            style: A prompt_toolkit Style object for colored output.
         """
         self.file_manager = file_manager
         self.git_manager = git_manager
         self.input_func = input_func
         self.logger = logging.getLogger(__name__)
+        self.style = style
 
         self.python_linter = PythonLinter()
         self.html_linter = HTMLLinter()
         self.css_validator = CssValidator()
 
-    def apply_edits(
+    async def apply_edits(
         self, edits: List[Tuple[str, str, str]]
     ) -> Tuple[bool, List[int], Set[str], Dict[str, str]]:
         """
@@ -113,9 +118,10 @@ class CodeApplier:
                         allow_edit = False
                         self.logger.warning(f"Skipping creation of {COLORS['CYAN']}{rel_path}{RESET} due to 'skip all' decision.")
                     else:
-                        confirm = self.input_func(
-                            f"LLM wants to create new file '{COLORS['CYAN']}{rel_path}{RESET}'. Allow? (y/N/a[llow all]/s[kip all]): "
-                        ).lower()
+                        confirm = await self.input_func(
+                           f"LLM wants to create new file '{rel_path}'. Allow? (y/N/a[llow all]/s[kip all]): "
+                        )
+                        confirm = confirm.lower()
                         if confirm in ['y', 'yes', 'a', 'allow all']:
                             allow_edit = True
                             if confirm in ['a', 'allow all']:
@@ -125,8 +131,8 @@ class CodeApplier:
                             if confirm in ['s', 'skip all']:
                                 creation_decision = 'skip_all'
                 else: # File exists, but is not in context
-                    confirm = self.input_func(
-                        f"LLM wants to edit '{COLORS['CYAN']}{rel_path}{RESET}' which is not in the chat. Allow? (y/N): "
+                    confirm = await self.input_func(
+                        f"LLM wants to edit '{rel_path}' which is not in the chat. Allow? (y/N): "
                     )
                     if confirm.lower() == 'y':
                         allow_edit = True
@@ -236,7 +242,7 @@ class CodeApplier:
                                 new_content_normalized,
                             )
                         edited_file_content[rel_path] = new_content_normalized # Update in-memory content
-                        self.logger.info(
+                        self.logger.debug(
                             f"Prepared edit {i+1} for {COLORS['CYAN']}{rel_path}{RESET}"
                         )
                     else:
@@ -283,14 +289,14 @@ class CodeApplier:
                 needs_write = True
             
             if needs_write:
-                self.logger.info(f"Writing final changes to {COLORS['CYAN']}{rel_path}{RESET}...")
+                self.logger.debug(f"Writing final changes to {COLORS['CYAN']}{rel_path}{RESET}...")
                 if self.file_manager.write_file(abs_path, final_content_in_memory):
                     modified_files_on_disk.add(rel_path)
                     if rel_path in files_created_in_this_run:
                         self.logger.info(f"Successfully created/wrote {COLORS['GREEN']}{rel_path}{RESET}")
                     else:
                         self.logger.info(
-                            f"Successfully saved changes to {COLORS['GREEN']}{rel_path}{RESET}"
+                            f"💾 {COLORS['GREEN']}{rel_path}{RESET}"
                         )
                 else:
                     self.logger.error(
@@ -337,19 +343,7 @@ class CodeApplier:
         self, rel_path: str, original_content: str, new_content: str
     ) -> None:
         """
-        Prints a unified diff of changes between two strings to the console with expanded context.
-
-        Compares the original content with the new content and displays the differences
-        with more context lines (10 lines) and without the @@ markers for cleaner output.
-        Visually separates different edit sections for better readability.
-
-        Args:
-            rel_path: The relative path of the file being diffed, used in the diff header.
-            original_content: The original string content before the changes.
-            new_content: The new string content after the changes.
-
-        Side Effects:
-            Prints the diff output directly to the standard output using logger.
+        Prints a unified diff using prompt_toolkit for styled output.
         """
         diff = difflib.unified_diff(
             original_content.splitlines(keepends=True),
@@ -357,43 +351,27 @@ class CodeApplier:
             fromfile=f"{rel_path} (original)",
             tofile=f"{rel_path} (modified)",
             lineterm="",
-            n=10
+            n=10,
         )
         diff_output = list(diff)
-
         if not diff_output:
             return
 
-        self.logger.info(f"--- Diff for {COLORS['CYAN']}{rel_path}{RESET} ---")
-        diff_lines = []
-        in_edit_block = False
-        found_change = False
-        
+        formatted_diff = []
+        formatted_diff.append(("class:diff.header", f"--- Diff for {rel_path} ---\n"))
+
         for line in diff_output:
-            line = line.rstrip("\n")  # Remove trailing newline for cleaner printing
-            
-            if line.startswith("+++") or line.startswith("---"):
-                # Skip the file header lines for cleaner output
+            line = line.rstrip("\n")
+            if line.startswith("+++") or line.startswith("---") or line.startswith("@@"):
                 continue
-            elif line.startswith("@@"):
-                # When we hit a new @@ marker, insert a separator if we were in an edit block
-                if in_edit_block and found_change:
-                    diff_lines.append("-" * 40)  # Visual separator between edit sections
-                in_edit_block = True
-                found_change = False
-                continue  # Skip the @@ position markers
             
-            # Track if we've found any actual changes in this edit block
-            if line.startswith("+") or (line.startswith("-") and not line.startswith("---")):
-                found_change = True
-            
-            # Format the line with color
             if line.startswith("+"):
-                diff_lines.append(f"{COLORS['GREEN']}{line}{RESET}")
-            elif line.startswith("-") and not line.startswith("---"):
-                diff_lines.append(f"{COLORS['RED']}{line}{RESET}")
+                formatted_diff.append(("class:diff.plus", f"{line}\n"))
+            elif line.startswith("-"):
+                formatted_diff.append(("class:diff.minus", f"{line}\n"))
             else:
-                diff_lines.append(line)
-                
-        self.logger.info("\n".join(diff_lines))
-        self.logger.info(f"--- End Diff for {COLORS['CYAN']}{rel_path}{RESET} ---")
+                formatted_diff.append(("", f"{line}\n"))
+        
+        formatted_diff.append(("class:diff.header", f"--- End Diff for {rel_path} ---\n"))
+        
+        print_formatted_text(FormattedText(formatted_diff), style=self.style)
